/*
 * Anarres C Preprocessor
 * Copyright (C) 2007 Shevek
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package org.anarres.cpp;

import java.io.File;

public class ErrorMessage {
	private String	source;
	private int		line;
	private int		column;
	private boolean	error;
	private String	msg;

	/**
	 * @param error true if an error, false if a warning.
	 */
	public ErrorMessage(Source source, int line, int column,
					boolean error, String msg) {
		this.source = String.valueOf(source);
		this.line = line;
		this.column = column;
		this.error = error;
		this.msg = msg;
	}

	/**
	 * @param postok The token at the error location.
	 * @param error true if an error, false if a warning.
	 */
	public ErrorMessage(Source source, Token postok,
					boolean error, String msg) {
		this(source, postok.getLine(), postok.getColumn(), error, msg);
	}

	/**
	 * Returns a text description of the file or other location
	 * in which this error occurred.
	 *
	 * This is always the String form of the Source passed to the
	 * constructor.
	 *
	 * @see StringLexerSource#toString()
	 * @see FileLexerSource#toString()
	 */
	public String getSource() {
		return source;
	}

	/**
	 * Returns the line number at which this error occurred.
	 *
	 * Line numbers start from zero.
	 */
	public int getLine() {
		return line;
	}

	/**
	 * Returns the column number at which this error occurred.
	 *
	 * Column numbers start from zero.
	 */
	public int getColumn() {
		return column;
	}

	/**
	 * Returns the error message itself.
	 */
	public String getMessage() {
		return msg;
	}

	/**
	 * Returns a user-readable version of this ErrorMessage.
	 */
	public String toString() {
		return getSource() + ":" +
				getLine() + ":" + getColumn() +
				(error ? ": error: " : ": warning: ") +
				msg;
	}
}
